# -*-coding:utf-8-*-

"""
A DAG timely visualiser.

Draw DAG tasks under selected parameters.
"""

from __future__ import unicode_literals

__all__ = ["run"]

import tornado.httpclient
import tornado.httpserver
import tornado.ioloop
import tornado.netutil
import tornado.web
import tornado.escape
from tornado.log import enable_pretty_logging
enable_pretty_logging()


import logging
logger = logging.getLogger("luiti.server")


# 1. Setup business package env
# list current package's related tasks, group by package name.
from .handlers import web_handlers


def app():
    settings = {
        "unescape": tornado.escape.xhtml_unescape,
        # "autoreload": True
    }

    api_app = tornado.web.Application(web_handlers, **settings)
    return api_app


def run(address, api_port):
    """
    Runs one instance of the API server.
    """
    api_app = app()

    api_sockets = tornado.netutil.bind_sockets(api_port, address=address)
    server = tornado.httpserver.HTTPServer(api_app)
    server.add_sockets(api_sockets)

    logger.info("Scheduler starting up")
    tornado.ioloop.IOLoop.instance().start()



# -*-coding:utf-8-*-

__all__ = ["TaskInit", "ArrowParameter", "TaskBase", "HadoopExt", "RootTask"]


from .task_init import TaskInit
from .parameter import ArrowParameter
from .task_base import TaskBase
from .hadoop_ext import HadoopExt
from .root_task import RootTask



# -*-coding:utf-8-*-

__all__ = ["TaskHour", "TaskDay", "TaskWeek", "TaskMonth", "TaskRange",
           "TaskDayHadoop", "TaskWeekHadoop", "TaskRangeHadoop",
           "StaticFile", "MongoImportTask", ]


from .time.task_hour import TaskHour
from .time.task_day import TaskDay
from .time.task_week import TaskWeek
from .time.task_month import TaskMonth
from .time.task_range import TaskRange

from .time.task_day_hadoop import TaskDayHadoop
from .time.task_week_hadoop import TaskWeekHadoop
from .time.task_range_hadoop import TaskRangeHadoop

from .other.static_file import StaticFile
from .other.mongo_import_task import MongoImportTask



# -*-coding:utf-8-*-

__all__ = ['luigi', 'config', "VisualiserEnvTemplate",

           'TaskBase',
           'TaskHour',
           'TaskDay',
           'TaskDayHadoop',
           'TaskWeek',
           'TaskWeekHadoop',
           'TaskMonth',
           'TaskRange',
           'TaskRangeHadoop',

           'RootTask',
           'StaticFile',
           'MongoImportTask',
           'HadoopExt',

           'manager',

           'IOUtils', 'DateUtils', 'TargetUtils', 'HDFSUtils',
           'MRUtils', 'MathUtils', 'CommandUtils',
           'CompressUtils',

           'ArrowParameter',

           'os', 're', 'sys', 'defaultdict', 'json', 'cached_property',
           'arrow',

           'MrTestCase', ]

import os
import sys
import re
from collections import defaultdict
import json
from etl_utils import cached_property

from .luigi_decorators import luigi

from .task_templates import TaskHour, TaskDay, TaskWeek, TaskMonth, TaskRange, TaskDayHadoop, TaskWeekHadoop, TaskRangeHadoop, StaticFile, MongoImportTask


from . import manager
from .utils import IOUtils, DateUtils, TargetUtils, HDFSUtils, \
    MRUtils, MathUtils, CommandUtils, CompressUtils

import arrow
from .luigi_extensions import RootTask, TaskBase, ArrowParameter, HadoopExt

from .utils.visualiser_env_template import VisualiserEnvTemplate

from .tests import MrTestCase


config = manager.luiti_config

luigi.tmp_dir = "/tmp"  # default one
